@@ -5,15 +5,12 @@
 
 __all__ = ['X509Credentials', 'connectTLS', 'listenTLS']
 
-import socket
 from time import time
-from errno import EWOULDBLOCK, EINTR
 
 from twisted.python import failure
-from twisted.internet import main, base, interfaces, address, tcp, error
-from twisted.internet.protocol import BaseProtocol
+from twisted.internet import main, base, interfaces, abstract, tcp, error
 
-from zope.interface import implements, implementsOnly, implementedBy
+from zope.interface import implementsOnly, implementedBy
 
 from gnutls.connection import ClientSession, ServerSession, ServerSessionFactory
 from gnutls.connection import X509Credentials as _X509Credentials
@@ -111,7 +108,7 @@ class TLSMixin:
         try:
             self._sendCloseReason(reason)
             self._sendCloseAlert(SHUT_RDWR)
-        except Exception, e:
+        except Exception:
             pass
 
     def _postLoseConnection(self):
@@ -223,7 +220,7 @@ class TLSClient(TLSMixin, tcp.Client):
     def loseConnection(self, reason=failure.Failure(main.CONNECTION_DONE)):
         reason = failure.Failure(reason) # accept python exceptions too
         self._close_reason = reason.value
-        tcp.Client.loseConnection(self, reason)
+        abstract.FileDescriptor.loseConnection(self, reason)
 
     def connectionLost(self, reason):
         if self.__watchdog is not None:
@@ -248,7 +245,6 @@ class TLSConnector(base.BaseConnector):
 class TLSServer(TLSMixin, tcp.Server):
     """Add TLS capabilities to a TCP server"""
     
-    #implements(interfaces.ISSLTransport)
     implementsOnly(interfaces.ISSLTransport, *[i for i in implementedBy(tcp.Server) if i != interfaces.ITLSTransport])
     
     def __init__(self, sock, protocol, client, server, sessionno, *args, **kw):
@@ -336,13 +332,14 @@ class TLSPort(tcp.Port):
 
     transport = TLSServer
 
-    def __init__(self, port, factory, credentials, backlog=50, interface='', reactor=None):
+    def __init__(self, port, factory, credentials, backlog=50, interface='', reactor=None, session_class=ServerSession):
         tcp.Port.__init__(self, port, factory, backlog, interface, reactor)
         self.credentials = credentials
+        self.session_class = session_class
 
     def createInternetSocket(self):
         sock = tcp.Port.createInternetSocket(self)
-        return ServerSessionFactory(sock, self.credentials, ServerSession)
+        return ServerSessionFactory(sock, self.credentials, self.session_class)
 
 
 def connectTLS(reactor, host, port, factory, credentials, timeout=30, bindAddress=None, server_name=None):
@@ -351,8 +348,8 @@ def connectTLS(reactor, host, port, factory, credentials, timeout=30, bindAddres
     return c
 
 
-def listenTLS(reactor, port, factory, credentials, backlog=50, interface=''):
-    p = TLSPort(port, factory, credentials, backlog, interface, reactor)
+def listenTLS(reactor, port, factory, credentials, backlog=50, interface='', session_class=ServerSession):
+    p = TLSPort(port, factory, credentials, backlog, interface, reactor, session_class)
     p.startListening()
     return p
 
